AQUA-DUCT
=========

*Aqua-Duct* a new tool facilitating analysis of the flow of solvent
molecules in molecular dynamic simulations.

Visit our homepage at [aquaduct.pl](http://aquaduct.pl/).

## Overview

*Aqua-Duct* comprises of two main elements:

1.  aquaduct,
2.  valve.

*aquaduct* is a Python module. It is a collection of tools to trace
residues in MD simulation. *valve* is a driver Python script. It uses
*aquaduct* to perform such a tracing.

## Availability

*Aqua-Duct* is licensed under
`GNU GPL v3 license <https://www.gnu.org/licenses/gpl-3.0.en.html>`.

Source code is available at [github.com/TUNNELING-GROUP/aqua-duct](https://github.com/TUNNELING-GROUP/aqua-duct/).

Summary of the most important changes is available in our [changelog](docs/source/changelog.rst).

## Installation

*Aqua-Duct* can be easily installed via PyPi:

    pip install aquaduct

Detailed instructions on *Aqua-Duct* installation are available at
[aquaduct.pl/installation](http://www.aquaduct.pl/installation/).

To start using Aqua-Duct type:

    valve.py --help

## Troubleshooting

If you encounter any problems with installation do not hesitate to
contact us at [info@aquaduct.pl](mailto:info@aquaduct.pl?subject=Aqua-Duct). We are **REALLY** willing to help!

You can also contact us at [github.com/TUNNELING-GROUP/aqua-duct](https://github.com/TUNNELING-GROUP/aqua-duct/).

## Documentation

Documentation can be found on our homepage [aquaduct.pl/documentation](http://aquaduct.pl/documentation/).

The most recent documentation is also available at [TUNNELING-GROUP.github.io/aqua-duct](https://TUNNELING-GROUP.github.io/aqua-duct/).
